
![](https://raw.githubusercontent.com/epykure/epyk-materials/master/epyk_materials/static/images/epyklogo_whole_big.png)

### First Version out now!

An easy way to use Epyk with the Material Components extension.

Presentation
================================
This package will make a simple interface between most of the components of Materials components
and Epyk. This addon will allow you to benefit from the two world and to keep write Interactive and modern web pages from Python.

https://material-ui.com/

Compatibility
================================
epyk is compatible with the most common Web Python Frameworks (Flask and Django).
By default, the server package embeds a Flask app as it is easier to install and ready to use.

The Extension (with Epyk-UI) can be included within a Jupyter or JupyterLab project. But this will lead to some limitations - for example Ajax and Socket will not be available.

The Material extension will add extra components with a more advanced design. Those components are integrated within
the framework and all the underlying event, interactivities and styling features can be reused.

Also it is possible to mix the components and to use Epyk-UI ecosystem with Material UI.

  